clear
load('Dimensional_values.mat')

global Rinf
global Rc
global Hs
global Hd
global Ns

global G
global B
global eps
global g
global num_k
global m_sim
global num_m

global Dw
global Fw

Ns    = 512;            % number of collocation points
num_k = 128;            % truncation of wavenumbers
num_jumps = 12 * 1000;  % number of jumps in simulation

%% Option 1: choose geometry from those used in the paper (80 Hz shaking)
load('GamF_vec_freq80.mat')
index = 41; % determines which corral to consider (value from 1 to 81)
Rc_dim = Rc_vec(index);
Gam_F  = GamF_vec(index);

Gam = 0.93 * Gam_F;

%% Option 2: choose another geometry/frequency (uncomment!)
% Rc_dim = 10 * 1e-3;     % corral step radius (m)
% Hd_dim = 6.6 * 1e-3;    % deep depth (m)
% Hs_dim = 0.6 * 1e-3;    % shallow depth (m)
% Rinf_dim = 64 * 1e-3;   % far-field radius (m)
% 
% Gam = 4.42;             % vibrational forcing (dimensionless)
% freq = 80;              % frequency (Herz)

%% Display simulation information
disp('------------------------------------')
disp(['Corral radius = ' num2str(Rc_dim*1000) ' mm, Gamma = ' num2str(Gam) ])
disp('------------------------------------')

%% angular modes
m_min = 0; % always zero!
m_max = 22; % <<< Need to increase m_max for larger domain size (Rc) >>>
m_vec = m_min:m_max;
num_m = length(m_vec);

m_sim = repmat(m_vec, num_k, 1);

%% Droplet information
R0_dim   = 0.35 * 1e-3;                     % droplet radius (m)
mass_dim = 4/3  * pi * R0_dim^3 * rho_dim;  % droplet mass (kg)
thI = 1.43 * pi;                            % impact phase
c   = 0.17;                                 % skidding friction (MB2013b)

%% Dimensionless variables (do not change)
Rc   = 1;               % radius of inner corral
Rinf = Rinf_dim/Rc_dim; % radius of outer corral (large)                 
Hs   = Hs_dim/Rc_dim;   % shallow depth
Hd   = Hd_dim/Rc_dim;   % deep depth

TF_dim = 2/freq;        % subharmonic period (dimensional, seconds)

% --- fluid coefficients ---
G   = g_dim * TF_dim^2/Rc_dim;
B   = sig_dim * TF_dim^2/(rho_dim * Rc_dim^3);
eps = nu_eff_dim * TF_dim/Rc_dim^2; % inverse Reynold's number

% --- droplet coefficients ---
Ci = c * sqrt(rho_dim * R0_dim/sig_dim) * g_dim * TF_dim;
Ca = 6*pi * R0_dim * mu_air_dim * TF_dim/mass_dim;
d0 = 1/Rc_dim * (mass_dim * g_dim * TF_dim^2/(rho_dim * Rc_dim^3));

Dw = 1 - exp(-(Ci + Ca));
Fw = (1 - exp(-Ci))/Ci  *  (1 - exp(-Ca))/Ca  *  d0 * G;   

% --- shaking information ---
g = @(t) 1 - Gam * cos(4 * pi * t + thI);

%% initialise system
% random initial position within corral
Xn = rand([2,1]) * 2 - 1; % random position on the square (-1,1)^2
while norm(Xn,2) >= 1
    Xn = rand(2,1) * 2 - 1;
end

% random initial velocity
u0_dim = 3 * 1e-3; % m/s % nominal initial velocity
u0_nondim = u0_dim * TF_dim/Rc_dim; % dimensionless
Un = u0_nondim * randn([2,1]);

% initialise free surface (eta) and velocity potential (phi) from rest
% computations are performed in Hankel space
eta_h = zeros(size(m_sim));
phi_h = zeros(size(m_sim));

%% make fundamental matrices for fluid evolution
get_fundamental_matrices

%% run simulation
disp('Start Simulation')
Run_simulation

%% Plot results
Plot_simulation



