function out = ODE_RK4(t,y,dt)
% fourth-order Runge-Kutta method, with integrating factor
global D

j1 = dt * D .* ODE_func(t,          y);
j2 = dt *      ODE_func(t + dt/2,   D.*y + j1/2);
j3 = dt *      ODE_func(t + dt/2,   D.*y + j2/2);
j4 = dt *      ODE_func(t + dt, D.*(D.*y + j3) );

l1 = D.* j1;
l2 = D.* j2;
l3 = D.* j3;
l4 =     j4;

out = D.^2 .* y + 1/6 * (l1 + 2*l2 + 2*l3 + l4);

end

%%
function out = ODE_func(t, y)
% RHS of odes, once integrating factor is adopted
global ks_mat
global g
global G
global B
global phi_ind
global eta_ind

eta = y(eta_ind, :);
phi = y(phi_ind, :);

f_eta = getDTN(phi);
f_phi = -(G * g(t) * eta) - (B * ks_mat.^2 .* eta);

out = [f_eta; f_phi];

end

%%
function DTNm = getDTN(fm)
% compute the DtN for a given spectral representation fm, for given m
global Ldtn
global Udtn
global pdtn
global Cdtn
global Nd
global Ns
global ks_mat
global Hs
global num_k

bm = [Cdtn * fm; zeros(Nd,2*num_k)];
xm = Udtn\(Ldtn\bm(pdtn, :));
gm = xm(1:Ns, :);

DTNm  = ks_mat .* (fm .* coth(ks_mat * Hs) - gm .* csch(ks_mat * Hs));
end