%% select range of data for plotting
range = num_jumps + (-1000:0);

x     = X_vec(1,range).'; 
y     = X_vec(2,range).';
speed = sqrt(sum(U_vec.^2,1));

% dimensional speed
sp = ( Rc_dim/TF_dim * 1000 ) * speed(range).';

%% Trajectory plot
figure
plot(x, y, 'b', 'LineWidth', 1)
thth = linspace(0,2*pi,100);
hold on
plot(cos(thth),sin(thth), 'k', 'LineWidth', 2)
hold off
grid on; box on
axis([-1 1 -1 1])
axis square
set(gca, 'FontName', 'Times New Roman', 'FontSize', 18, ...
    'XTick', -1:0.5:1, 'YTick', -1:0.5:1)
xlabel('$$x/R_c$$', 'Interpreter','Latex', 'FontSize', 20)
ylabel('$$\frac{y}{R_c}$$', 'Interpreter','Latex', 'FontSize', 20)
set(get(gca, 'YLabel'), 'Rotation', 0)

%% Speed-trajectory plot
figure
surface([x x], [y y], [sp sp], ...
    'EdgeColor','flat', 'FaceColor','none', 'LineWidth', 2)
shading interp
colormap jet
colorbar
thth = linspace(0,2*pi,100);
hold on
plot(cos(thth),sin(thth), 'k', 'LineWidth', 2)
hold off
grid on; box on
axis([-1 1 -1 1])
axis square
set(gca, 'FontName', 'Times New Roman', 'FontSize', 18, ...
    'XTick', -1:0.5:1, 'YTick', -1:0.5:1)
xlabel('$$x/R_c$$', 'Interpreter','Latex', 'FontSize', 20)
ylabel('$$\frac{y}{R_c}$$', 'Interpreter','Latex', 'FontSize', 20)
title('Speed (mm/s)')
set(get(gca, 'YLabel'), 'Rotation', 0)

%% radius and angular momentum
rad = sqrt(sum(X_vec.^2,1)); z = zeros(1, num_jumps);
ang = [0 0 1] * cross([X_vec; z], [U_vec; z])/mean(speed(range));

figure
subplot(2,1,1)
plot(rad, 'b', 'LineWidth', 1)
axis([0 num_jumps 0 1])
grid on
set(gca, 'FontName', 'Times New Roman', 'FontSize', 18)
xlabel('$$n$$', 'Interpreter', 'Latex', 'FontSize', 20)
ylabel('$$|\mathbf{X}_n|$$', 'Interpreter', 'Latex', 'FontSize', 20)
set(get(gca, 'YLabel'), 'Rotation', 0)
title('Dimensionless radius')

subplot(2,1,2)
plot(ang, 'b', 'LineWidth', 1)
axis([0 num_jumps -1 1])
grid on
set(gca, 'FontName', 'Times New Roman', 'FontSize', 18)
xlabel('$$n$$', 'Interpreter', 'Latex', 'FontSize', 20)
ylabel('$$L_{z,n}$$', 'Interpreter', 'Latex', 'FontSize', 20)
set(get(gca, 'YLabel'), 'Rotation', 0)
title('Dimensionless angular momentum')

%% Frequency spectrum
log2jumps = 13;
T = 2^log2jumps;
range2 = num_jumps + ((-T+1):0);
rad2 = rad(range2);

fftrad = fft(rad2);

P2 = abs(fftrad/T);
P1 = P2(1:int64(T/2+1));
P1(2:end-1) = 2*P1(2:end-1);
freq_sim = 1/T * double((0:int64(T/2-1)));
power = P1(1:int64(T/2));

figure
semilogy(freq_sim, power, 'b')
axis([0 0.15 1e-6 1])

[pks, locs] = findpeaks(power);
freq_sub = freq_sim(locs (pks > 1e-4));
grid on
set(gca, 'FontName', 'Times New Roman', 'FontSize', 18)
xlabel('Frequency', 'Interpreter', 'Latex', 'FontSize', 20)
ylabel('Power', 'Interpreter', 'Latex', 'FontSize', 20);

%% find change in angle between successive radial maxima
range3 = 1000:num_jumps;
[pks,locs] = findpeaks(rad(range3));
X2 = X_vec(:,range3);
Xr = X2(:,locs);
dotp = sum(Xr(:,1:end-1).*Xr(:,2:end));
delta_th = acos(dotp./(pks(1:end-1) .* pks(2:end) ));
mean_delta_th = mean(delta_th);

disp(['Rotation angle = ' num2str(mean_delta_th/pi*180) ' degrees'])

%% maximum and minimum radii
[pks,~] = findpeaks(rad(range3));       % maximum values
maxA = mean(pks);

[pks,~] = findpeaks(-rad(range3));      % minimum values
minA = mean(-pks);

disp(['Radial range (A/R_c): ' num2str(minA) ' -- ' num2str(maxA) ])
