%% construct fundamental matrices

% *** do not changes this code ***

global ks
global Rinf
global Ldtn
global Udtn
global pdtn
global Cdtn
global Nd
global Ns

global eps
global phi_ind
global eta_ind
global num_k
global ks_mat
global k_sim

global Mat_cell
global D

% indices for eta and phi
eta_ind = (1:Ns).';
phi_ind = Ns + eta_ind;
s_ind  = [eta_ind(1:num_k); phi_ind(1:num_k)]; % subset of indices

% wavenumbers for fundamental matrix (truncate)
Mat_cell = cell(1,num_m);
k_sim    = zeros(num_k, num_m);
Me_vec   = zeros(1, num_m);         % vector of memories: M_m

% ODE solve timestep information (dimensionless units)
dt    = 2^(-7);                     % dimensionless timestep
t_vec = 0:dt:1;                     % over one Faraday period
num_t = length(t_vec);              % number of timesteps

% solve ODEs to construct fundamental matrices
disp('Pre-computation of fundamental matrices for each angular mode')
disp(['--- m ranges from 0 to ' num2str(m_max) '---'])
for ss = 1:num_m
    m = m_vec(ss);
    disp(['m = ' num2str(m)])
    ks    = zerobess('J', m, Ns)/Rinf; % shallow wavenumbers
    Mat   = zeros(2*Ns, 2*num_k);   % acts on [eta; phi]
    ks_mat= repmat(ks, 1, 2*num_k); % have 2*num_k initial conditions
    
    [Ldtn, Udtn, pdtn, Cdtn, Nd] = make_DTN_matrices(m);
    
    % intial conditions
    Mat(1:num_k, 1:num_k) = eye(num_k);
    Mat(Ns + (1:num_k), num_k + (1:num_k)) = eye(num_k);
    
    % matrix D is used for integrating factor (for dissipation)
    gamma = 2*eps*ks_mat.^2;
    D     = repmat(exp(-gamma*dt/2), 2, 1);

    % ODE solve - introduce integrating factor at each timestep
    for jj = 1:(num_t - 1)
        Mat = ODE_RK4(t_vec(jj), Mat, dt);
    end

    % truncate to square fundamental matrix
    Mat = Mat(s_ind, :); 
    
    % store variables
    Mat_cell{ss} = Mat;
    k_sim(:,ss) = ks(1:num_k);
    
    % --- get memory ---
    [~,eig_vec] = eig(Mat, 'vector');
    rDind = (eig_vec == real(eig_vec));
    Dr    = eig_vec(rDind);
    Me_vec(ss) = -1/log( max(Dr) );
    if Me_vec(ss) < 0
        disp('Need to reduce the vibrational forcing')
        break
    end  
end

