function grad = get_grad_wavefield(r, th, eta_h)
% computes the wave field gradient at polar position (r,th)
% eta_h is the matrix giving the spectral representation of eta_h
global m_sim
global k_sim
% rotation matrix
rotat = [cos(th), -sin(th); sin(th), cos(th)];

m_sim1 = m_sim(:,2:end); % for m >= 1
k_sim1 = k_sim(:,2:end); % for m >= 1
eta_h1 = eta_h(:,2:end); % for m >= 1

k_sim0 = k_sim(:,1);     % for m = 0
eta_h0 = eta_h(:,1);     % for m = 0

Jm_minus = besselj(m_sim1(:) - 1, k_sim1(:) * r);
Jm_plus  = besselj(m_sim1(:) + 1, k_sim1(:) * r);
J0_plus  = besselj(1, k_sim0 * r);

% gradient in polar coordinates
er_coeff  = -1 * sum(k_sim0 .* J0_plus .* eta_h0) + ...
    sum( k_sim1(:) .* (Jm_minus - Jm_plus) .* ...
    real(eta_h1(:) .* exp(1i * m_sim1(:) * th)) );

eth_coeff = -1 * sum( k_sim1(:) .* (Jm_minus + Jm_plus) .* ...
    imag(eta_h1(:) .* exp(1i * m_sim1(:) * th)) );

% convert to Cartesian coordinates
grad = rotat * [er_coeff; eth_coeff];

end