function [Ldtn, Udtn, pdtn, Cdtn, Nd] = make_DTN_matrices(m)
global ks
global Rinf
global Rc
global Ns
global Hd
global Hs

% first collocation point in shallow layer
if m == 0
    minr = 0;
else
    minr = Rinf*ks(1)/ks(end);
end
maxr = Rinf * (1-1/(2*Ns));

% --- definition of collocation points ---
DR = maxr - minr;
Nd = round(Ns * (Rc - minr)/DR);
rd = linspace(minr, Rc, Nd + 1); rd = rd(1:end-1);
rs = linspace(Rc, maxr, Ns-Nd);
rc = [rd, rs];
% -----------------------------------------

Hdiff = Hd - Hs;

% wavenumbers (includes zero for m == 0)
kd = zerobess('DJ', m, Nd)/Rc;

% make meshes -----------------------------------------------------------
% for matching condition
[kdm, rdm] = meshgrid(kd,rd);
[ksm, rsm] = meshgrid(ks,rc);

% for consistency condition
[ksm_c, rsm_c] = meshgrid(ks, rd);

% make matrices --------------------------------------------------------
% for matching condition
Asm = ksm .* coth(ksm * Hs) .* besselj(m, ksm .* rsm);

Adm = zeros(Ns, Nd);
Adm(1:Nd, :) = kdm .* tanh(kdm * Hdiff) .* besselj(m, kdm .* rdm);

% consistency condition
Bsm = besselj(m, ksm_c .* rsm_c);
Bdm = besselj(m, kdm .* rdm);

% coefficient of f
Csm = ksm .* csch(ksm * Hs) .* besselj(m, ksm .* rsm);

A = [Asm, Adm; Bsm, -Bdm];

% OUTPUT -----------------------------
[Ldtn,Udtn,pdtn] = lu(A,'vector');
Cdtn = Csm;

end
